==> haskell-data-endian-0.1.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-endian.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-endian
version: 0.1.1
id: data-endian-0.1.1-LZbtoj85OezF7hILfqR1PR
key: data-endian-0.1.1-LZbtoj85OezF7hILfqR1PR
license: BSD3
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-endian
synopsis: Endian-sensitive data
description:
    This package provides helpers for converting endian-sensitive data.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Endian
abi: f77c6144da527110440c108c8386f134
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-endian-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-endian-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/data-endian-0.1.1
hs-libraries: HSdata-endian-0.1.1-LZbtoj85OezF7hILfqR1PR
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-data-endian/html/data-endian.haddock
haddock-html: /usr/share/doc/haskell-data-endian/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-endian-0.1.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-endian.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-endian
version: 0.1.1
id: data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek
key: data-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek
license: BSD-3-Clause
copyright: 2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-endian
synopsis: Endian-sensitive data
description:
    This package provides helpers for converting endian-sensitive data.
category: Data
abi: f759f6c0a46b81c455ff375b38f7419b
exposed: True
exposed-modules:
    Data.Endian
import-dirs: /usr/lib/ghc-8.4.2/site-local/data-endian-0.1.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/data-endian-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/data-endian-0.1.1
hs-libraries: HSdata-endian-0.1.1-Hq7bxn6bh65QNiKhqKtek
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-data-endian/html/data-endian.haddock
haddock-html: /usr/share/doc/haskell-data-endian/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
